__author__ = 'Kiril Savino'

from hack import Hack, set_default_backend
from version_hack import VersionHack
from backend import Backend
from redis_backend import RedisBackend
